using UnityEngine;
using System.Collections;

public class CameraDetector : MonoBehaviour {
    public float dangerLevel = 0f;
    public float maxDangerLevel = 3f;
    public float alarmDangerLevel = 2.5f;
    private bool seeingStuff = false;
	public bool isSeeingStuff { get { return seeingStuff; } }

    public GamestateHandler gamestateHandler;
    private Transform seenObject;

    float maxAlertDist = 300f;
    float alertMultiplier = 1f;

    public bool broken = false;

    void Start()
    {
        camera.aspect = 1.1f;

        maxAlertDist = new Vector3(400, 300, 0).magnitude;
    }

    Vector3[] corners = new Vector3[8];

    public void Detected(Transform whatWasSeen)
    {
        seenObject = whatWasSeen;

        BoxCollider box = whatWasSeen.GetComponentInChildren<BoxCollider>();
        Vector3 extents = box.extents;
        extents.x *= box.transform.localScale.x;
        extents.y *= box.transform.localScale.y;
        extents.z *= box.transform.localScale.z;
        extents = box.transform.TransformDirection(extents);

        Vector3 startPos = box.transform.position;

        // Check if box is hidden behind something
        bool isHidden = true;

        corners[0] = startPos + new Vector3(extents.x, extents.y, extents.z);
        corners[1] = startPos + new Vector3(-extents.x, extents.y, extents.z);
        corners[2] = startPos + new Vector3(extents.x, -extents.y, extents.z);
        corners[3] = startPos + new Vector3(-extents.x, -extents.y, extents.z);
        corners[4] = startPos + new Vector3(-extents.x, -extents.y, -extents.z);
        corners[5] = startPos + new Vector3(extents.x, -extents.y, -extents.z);
        corners[6] = startPos + new Vector3(-extents.x, extents.y, -extents.z);
        corners[7] = startPos + new Vector3(extents.x, extents.y, -extents.z);

        Vector3 camPos = transform.position;
        RaycastHit hit;
        foreach (Vector3 corner in corners)
        {
            Vector3 direction = corner - camPos;
            if (Physics.Raycast(camPos, direction, out hit))
            {
                if (hit.collider.transform == whatWasSeen || hit.collider == box)
                {
                    isHidden = false;
                    break;
                }
            }
        }

        seeingStuff = !isHidden;
    }

    private bool firstTime = true;
    private void FirstTime()
    {
        gamestateHandler = Camera.main.GetComponent<GamestateHandler>();
    }
    void Update()
    {
        if (firstTime)
        {
            FirstTime();
            firstTime = false;
        }

        if (seeingStuff)
        {
            float centerToBoxLength = (camera.WorldToScreenPoint(seenObject.transform.position) - new Vector3(400, 0, 300)).magnitude;
            alertMultiplier = 1 - Mathf.Min((centerToBoxLength / maxAlertDist), 1);
            dangerLevel = Mathf.Min(maxDangerLevel, dangerLevel + 20f * Time.deltaTime * alertMultiplier);
        }
        else
        {
            dangerLevel = Mathf.Max(0, dangerLevel - 1f * Time.deltaTime);
        }

        if (dangerLevel >= alarmDangerLevel)
        {
            if(!broken)
                gamestateHandler.CameraSpottedPlayer();
        }

        seeingStuff = false;
    }
}
