using UnityEngine;
using System.Collections;

public class GamestateHandler : MonoBehaviour
{
    public enum GamestateEnum
    {
        Paused,
        JustStarted,
        PlayerSpotted,
        PlayerAlive,
        PlayerWon,
        GameEnteringNewLevel
    };

    public bool MenuShown = false;

    private GamestateEnum gameStateBeforePause;
    private GamestateEnum gameState;
    public GamestateEnum Gamestate() { return gameState; }

    public float secondsForIntro = 2;
    private float remainingSecondsForIntro;

    private bool playerSpotted = false;
    public void CameraSpottedPlayer() { playerSpotted = true; }

    private bool playerReachedGoal = false;
    public void GoalWasReached() { playerReachedGoal = true; }

    public GameObject MonkeyBox;
    private Vector3 boxPosition;
    private Quaternion boxRotation;

	// Use this for initialization
	void Start()
    {
        boxPosition = MonkeyBox.transform.position;
        boxRotation = MonkeyBox.transform.rotation;
        remainingSecondsForIntro = secondsForIntro;
        gameState = GamestateEnum.Paused;
        gameStateBeforePause = GamestateEnum.JustStarted;
	}
	
	// Update is called once per frame
	void Update()
    {
        if (Input.GetKeyDown(KeyCode.Escape) && gameState != GamestateEnum.Paused)
        {
            MenuShown = true;
            gameStateBeforePause = gameState;
            gameState = GamestateEnum.Paused;
        }
        switch (gameState)
        {
            case GamestateEnum.JustStarted:
                playerSpotted = false;
                playerReachedGoal = false;
                remainingSecondsForIntro = Mathf.Max(0, remainingSecondsForIntro - Time.deltaTime);
                if (remainingSecondsForIntro == 0)
                    gameState = GamestateEnum.PlayerAlive;
                break;
            case GamestateEnum.PlayerAlive:
                if (playerSpotted)
                {
                    gameState = GamestateEnum.PlayerSpotted;
                    playerSpotted = false;
                }
                else if (MenuShown)
                    gameState = GamestateEnum.Paused;
                else if (playerReachedGoal)
                {
                    playerReachedGoal = false;
                    gameState = GamestateEnum.PlayerWon;
                }
                break;
            case GamestateEnum.Paused:
                if (!MenuShown)
                    gameState = gameStateBeforePause;
                break;
            case GamestateEnum.GameEnteringNewLevel:

                if (Application.loadedLevel == Application.levelCount - 1)
                {
                    Application.LoadLevel(0);
                }
                else
                    Application.LoadLevel(Application.loadedLevel + 1);
                break;
            case GamestateEnum.PlayerWon:
            case GamestateEnum.PlayerSpotted:
            default:
                break;
        }
	}

    public Texture2D BlackTextureUseForFading;
    private float alphaFadeValue = 1f;
    void OnGUI()
    {
        if (gameState == GamestateEnum.JustStarted)
        {
            alphaFadeValue -= Mathf.Clamp01(Time.deltaTime / 5);

            GUI.color = new Color(1f, 1f, 1f, alphaFadeValue);
            GUI.DrawTexture(new Rect(0, 0, Screen.width, Screen.height), BlackTextureUseForFading);

        }
        else if (gameState == GamestateEnum.GameEnteringNewLevel)
        {
            alphaFadeValue += Mathf.Clamp01(Time.deltaTime / 5);

            GUI.color = new Color(1f, 1f, 1f, alphaFadeValue);
            GUI.DrawTexture(new Rect(0, 0, Screen.width, Screen.height), BlackTextureUseForFading);

        }
    }

    public void StartGame()
    {
        //MonkeyBox.transform.position = boxPosition;
        //MonkeyBox.transform.rotation = boxRotation;
        //gameState = GamestateEnum.JustStarted;
        //remainingSecondsForIntro = secondsForIntro;
        //MenuShown = false;
        Application.LoadLevel(Application.loadedLevel);
    }

    public void ProceedToNextLevel()
    {
        gameState = GamestateEnum.GameEnteringNewLevel;
    }
}
