using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class MenuHandler : MonoBehaviour
{
    public GamestateHandler GamestateHandler;

    public float Top = 200;
    public float Left = 280;
    public float Width = 200;

    public float MenuItemHeight = 26;
    public float SpaceBetweenTopBorderAndFirstItem = 26;
    public float SpaceBetweenMenuItems = 5;
    public float LeftAndRightMarginForMenuItems = 5;
    public float SpaceBetweenLastMenuItemAndBottom = 5;
    private Rect MenuPosition;

    public string[] MenuItemNames;
    public MenuFunction[] MenuItemFunctions;
    public enum MenuFunction
    {
        Resume,
        NewGame
    }

	// Use this for initialization
	void Start ()
    {
        if (MenuItemNames.Length != MenuItemFunctions.Length)
            Debug.LogError("Menu Item Names and Menu Item Functions MUST have the same number of items");
        else if (MenuItemNames.Length == 0)
        {
            MenuItemNames = new string[2];
            MenuItemNames[0] = "Resume Game";
            MenuItemNames[1] = "New Game";

            MenuItemFunctions = new MenuFunction[2];
            MenuItemFunctions[0] = MenuFunction.Resume;
            MenuItemFunctions[1] = MenuFunction.NewGame;
        }
	}
	
    private bool firstTime = true;
    private void FirstTime()
    {
        GamestateHandler = Camera.main.GetComponent<GamestateHandler>();
    }
    void Update()
    {
        if (firstTime)
        {
            FirstTime();
            firstTime = false;
        }
	}
    
    public void OnGUI()
    {
        if (GamestateHandler.MenuShown)
        {
            MenuPosition = new Rect(Left, Top, Width, MenuItemNames.Length * MenuItemHeight + MenuItemNames.Length * SpaceBetweenMenuItems - SpaceBetweenMenuItems + SpaceBetweenTopBorderAndFirstItem + SpaceBetweenLastMenuItemAndBottom);
            GUI.Box(MenuPosition, "Camera vs. Box");

            float firstMenuItemTop = Top + SpaceBetweenTopBorderAndFirstItem;
            for (int i = 0; i < MenuItemNames.Length; i++)
            {
                if(GUI.Button(new Rect(
                        Left + LeftAndRightMarginForMenuItems,
                        firstMenuItemTop + i * MenuItemHeight + i * SpaceBetweenMenuItems,
                        Width - 2 * LeftAndRightMarginForMenuItems, MenuItemHeight),
                        MenuItemNames[i]))
                    MenuItemActivated(MenuItemFunctions[i]);
            }
        }
    }

    private void MenuItemActivated(MenuFunction activatedItem)
    {
        switch (activatedItem)
        {
            case MenuFunction.Resume:
                GamestateHandler.MenuShown = false;
                break;
            case MenuFunction.NewGame:
                GamestateHandler.StartGame();
                break;
            default:
                break;
        }
    }
}
